"use client"

import { motion } from "framer-motion"
import { Loader2 } from "lucide-react"

interface LoadingSpinnerProps {
    size?: "sm" | "md" | "lg"
    message?: string
    fullHeight?: boolean
    className?: string
}

export default function LoadingSpinner({ size = "md", message, fullHeight = true, className }: LoadingSpinnerProps) {
    // Size mappings
    const sizeClasses = {
        sm: "h-6 w-6",
        md: "h-10 w-10",
        lg: "h-16 w-16",
    }

    // Container height
    const heightClass = fullHeight ? "min-h-[calc(100vh-4rem)]" : "min-h-[200px]"

    return (
        <div
            className={`flex flex-col justify-center items-center ${heightClass} ${className}`}
            role="status"
            aria-live="polite"
        >
            <div className="relative">
                {/* Background pulse effect */}
                <motion.div
                    initial={{ opacity: 0.5, scale: 0.8 }}
                    animate={{ opacity: [0.5, 0.2, 0.5], scale: [0.8, 1.1, 0.8] }}
                    transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY, ease: "easeInOut" }}
                    className="absolute inset-0 bg-emerald-500/10 dark:bg-emerald-500/5 rounded-full"
                    style={{
                        width: size === "sm" ? "24px" : size === "md" ? "40px" : "64px",
                        height: size === "sm" ? "24px" : size === "md" ? "40px" : "64px",
                    }}
                />

                {/* Spinner */}
                <motion.div
                    animate={{ rotate: 360 }}
                    transition={{ duration: 1.5, repeat: Number.POSITIVE_INFINITY, ease: "linear" }}
                >
                    <Loader2 className={`${sizeClasses[size]} text-emerald-600 dark:text-emerald-500`} />
                </motion.div>
            </div>

            {/* Optional loading message */}
            {message && (
                <motion.p
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 1 }}
                    transition={{ delay: 0.5, duration: 0.5 }}
                    className="mt-4 text-slate-600 dark:text-slate-400 text-sm font-medium"
                >
                    {message}
                </motion.p>
            )}

            <span className="sr-only">Loading</span>
        </div>
    )
}
